# Table of Contents

- [general-settings](<./general-settings.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [General Settings](<./General-Settings.md>)
  - [Tagging Mode](<./General-Settings/Tagging-Mode.md>)
  - [Quick Search Mode](<./General-Settings/Quick-Search-Mode.md>)
  - [Choosing Currency](<./General-Settings/Choosing-Currency.md>)
  - [Custom Fiscal Year](<./General-Settings/Custom-Fiscal-Year.md>)
  - [Idle Timeout Duration](<./General-Settings/Idle-Timeout-Duration.md>)
  - [Subscription Mode](<./General-Settings/Subscription-Mode.md>)
  - [Subscription Types](<./General-Settings/Subscription-Types.md>)
  - [Multiple Subscriptions](<./General-Settings/Multiple-Subscriptions.md>)
  - [Data Privacy](<./General-Settings/Data-Privacy.md>)
  - [User Segments](<./General-Settings/User-Segments.md>)
  - [Support Channels](<./General-Settings/Support-Channels.md>)
  - [Additional Settings](<./General-Settings/Additional-Settings.md>)
  - [Maintenance Mode](<./General-Settings/Maintenance-Mode.md>)
  - [Data Breach Contact](<./General-Settings/Data-Breach-Contact.md>)
  - [Workspace Snapshot](<./General-Settings/Workspace-Snapshot.md>)
  - [Was this page helpful?](<./General-Settings/Was-this-page-helpful.md>)
